SolveC

Trait SolveC 

pub trait SolveC<A: Scalar> {
    // Required method
    fn solvec_inplace<'a>(
        &self,
        b: &'a mut ArrayRef<A, Ix1>,
    ) -> Result<&'a mut ArrayRef<A, Ix1>>;

    // Provided methods
    fn solvec(&self, b: &ArrayRef<A, Ix1>) -> Result<Array1<A>> { ... }
    fn solvec_into<S: DataMut<Elem = A>>(
        &self,
        b: ArrayBase<S, Ix1>,
    ) -> Result<ArrayBase<S, Ix1>> { ... }
}
Solve systems of linear equations with Hermitian (or real symmetric) positive definite coefficient matrices

Required Methods

fn solvec_inplace<'a>( &self, b: &'a mut ArrayRef<A, Ix1>, ) -> Result<&'a mut ArrayRef<A, Ix1>>

Solves a system of linear equations A * x = b with Hermitian (or real symmetric) positive definite matrix A, where A is self, b is the argument, and x is the successful result. The value of x is also assigned to the argument.

Provided Methods

fn solvec(&self, b: &ArrayRef<A, Ix1>) -> Result<Array1<A>>

Solves a system of linear equations A * x = b with Hermitian (or real symmetric) positive definite matrix A, where A is self, b is the argument, and x is the successful result.

fn solvec_into<S: DataMut<Elem = A>>( &self, b: ArrayBase<S, Ix1>, ) -> Result<ArrayBase<S, Ix1>>

Solves a system of linear equations A * x = b with Hermitian (or real symmetric) positive definite matrix A, where A is self, b is the argument, and x is the successful result.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<A> SolveC<A> for ArrayRef<A, Ix2>
where A: Scalar + Lapack,

Source

fn solvec_inplace<'a>( &self, b: &'a mut ArrayRef<A, Ix1>, ) -> Result<&'a mut ArrayRef<A, Ix1>>

Implementors

Source

impl<A, S> SolveC<A> for CholeskyFactorized<S>
where A: Scalar + Lapack, S: Data<Elem = A>,