ReciprocalConditionNumInto

Trait ReciprocalConditionNumInto 

pub trait ReciprocalConditionNumInto<A: Scalar> {
    // Required method
    fn rcond_into(self) -> Result<A::Real>;
}
An interface for estimating the reciprocal condition number of matrices.

Required Methods

fn rcond_into(self) -> Result<A::Real>

Estimates the reciprocal of the condition number of the matrix in 1-norm.

This method uses the LAPACK *gecon routines, which estimate self.inv().opnorm_one() and then compute rcond = 1. / (self.opnorm_one() * self.inv().opnorm_one()).

  • If rcond is near 0., the matrix is badly conditioned.
  • If rcond is near 1., the matrix is well conditioned.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<A, S> ReciprocalConditionNumInto<A> for ArrayBase<S, Ix2>
where A: Scalar + Lapack, S: DataMut<Elem = A> + RawDataClone,

Implementors

Source

impl<A, S> ReciprocalConditionNumInto<A> for LUFactorized<S>
where A: Scalar + Lapack, S: Data<Elem = A> + RawDataClone,