ExtractTridiagonal

Trait ExtractTridiagonal 

pub trait ExtractTridiagonal<A: Scalar> {
    // Required method
    fn extract_tridiagonal(&self) -> Result<Tridiagonal<A>>;
}
An interface for making a Tridiagonal struct.

Required Methods

fn extract_tridiagonal(&self) -> Result<Tridiagonal<A>>

Extract tridiagonal elements and layout of the raw matrix.

If the raw matrix has some non-tridiagonal elements, they will be ignored.

The shape of raw matrix should be equal to or larger than (2, 2).

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<A> ExtractTridiagonal<A> for ArrayRef<A, Ix2>
where A: Scalar + Lapack,

Implementors