ReciprocalConditionNumTridiagonal

Trait ReciprocalConditionNumTridiagonal 

pub trait ReciprocalConditionNumTridiagonal<A: Scalar> {
    // Required method
    fn rcond_tridiagonal(&self) -> Result<A::Real>;
}
An interface for estimating the reciprocal condition number of tridiagonal matrix refs.

Required Methods

fn rcond_tridiagonal(&self) -> Result<A::Real>

Estimates the reciprocal of the condition number of the tridiagonal matrix in 1-norm.

This method uses the LAPACK *gtcon routines, which estimate self.inv_tridiagonal().opnorm_one() and then compute rcond = 1. / (self.opnorm_one() * self.inv_tridiagonal().opnorm_one()).

  • If rcond is near 0., the matrix is badly conditioned.
  • If rcond is near 1., the matrix is well conditioned.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<A> ReciprocalConditionNumTridiagonal<A> for ArrayRef<A, Ix2>
where A: Scalar + Lapack,

Implementors