Trait ndarray_linalg::solveh::InverseHInto
[−]
[src]
pub trait InverseHInto {
type Output;
fn invh_into(self) -> Result<Self::Output>;
}An interface for inverting Hermitian (or real symmetric) matrices.
Associated Types
type Output
Required Methods
fn invh_into(self) -> Result<Self::Output>
Computes the inverse of the Hermitian (or real symmetric) matrix.
Warning: The inverse is stored only in the upper triangular portion of the result matrix! If you want the lower triangular portion to be correct, you must fill it in according to the results in the upper triangular portion.
Implementations on Foreign Types
impl<A, S> InverseHInto for ArrayBase<S, Ix2> where
A: Scalar,
S: DataMut<Elem = A>, [src]
A: Scalar,
S: DataMut<Elem = A>,