pub trait ExtractTridiagonal<A: Scalar> {
// Required method
fn extract_tridiagonal(&self) -> Result<Tridiagonal<A>>;
}Expand description
An interface for making a Tridiagonal struct.
Required Methods
Sourcefn extract_tridiagonal(&self) -> Result<Tridiagonal<A>>
fn extract_tridiagonal(&self) -> Result<Tridiagonal<A>>
Extract tridiagonal elements and layout of the raw matrix.
If the raw matrix has some non-tridiagonal elements, they will be ignored.
The shape of raw matrix should be equal to or larger than (2, 2).
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".